/**
 * Pointillism
 * by Daniel Shiffman. 
 * 
 * Mouse horizontal location controls size of dots. 
 * Creates a simple pointillist effect using ellipses colored
 * according to pixels in an image. 
 * 
 * Updated 27 February 2010.
 */
 
 /* ----------------- Processing code --------------------- */
/**
 * oscP5broadcastClient by andreas schlegel
 * an osc broadcast client.
 * an example for broadcast server is located in the oscP5broadcaster example.
 * oscP5 website and all downloads available at http://www.sojamo.de/oscP5
 */
 
 /*
 * code adapted by Richard Hoadley, 2011
 * rhoadley.net
 * v0.1
 */
 
import oscP5.*;
import netP5.*;
 
OscP5 oscP5;

/* pointillism */
PImage img;

int smallPoint = 2;
int largePoint;
int top, left;
int x=0, y=0;
 
/* a NetAddress contains the ip address and port number of a remote location in the network. */
NetAddress myBroadcastLocation; 
 
void setup() {
  size(400,400);
  frameRate(25);
 
  /* create a new instance of oscP5. 
   * 12000 is the port number you are listening for incoming osc messages.
   */
  oscP5 = new OscP5(this,12000);
 
  /* create a new NetAddress. a NetAddress is used when sending osc messages
   * with the oscP5.send method.
   */
 
  /* the address of the osc broadcast server */
  myBroadcastLocation = new NetAddress("127.0.0.1",57120);
  
  size(200, 200);
  img = loadImage("eames.jpg");
  //img = loadImage("sunflower.jpg");  // an alternative image
  noStroke();
  background(255);
  smooth();
  largePoint = min(width, height) / 10;
  // center the image on the screen
  left = (width - img.width) / 2;
  top = (height - img.height) / 2;
}
 
void mousePressed() {
  /* create a new OscMessage with an address pattern, in this case /test. */
 // OscMessage myOscMessage = new OscMessage("/test");
  OscMessage myOscMessage;
  myOscMessage = new OscMessage("/test");

  /* add a value (an integer) to the OscMessage */
  myOscMessage.add(100);  
  println(myBroadcastLocation);
  /* send the OscMessage to a remote location specified in myNetAddress */
  oscP5.send(myOscMessage, myBroadcastLocation);
}
 
void keyPressed() {
  OscMessage m;
  switch(key) {
    case('c'):
      /* connect to the broadcaster */
      println("you pressed c");
      m = new OscMessage("/server/connect",new Object[0]);
      oscP5.flush(m,myBroadcastLocation);  
      break;
    case('d'):
      /* disconnect from the broadcaster */
      m = new OscMessage("/server/disconnect",new Object[0]);
      oscP5.flush(m,myBroadcastLocation);  
      break;
 
  }  
}
 
/* incoming osc message are forwarded to the oscEvent method. */
void oscEvent(OscMessage theOscMessage) {
  /* get and print the address pattern and the typetag of the received OscMessage */
  println("### received an osc message with addrpattern "+theOscMessage.addrPattern()+" and typetag "+theOscMessage.typetag());
  theOscMessage.print();
}
 




void draw() { 
  // background(0);
  float pointillize = map(mouseX, 0, width, smallPoint, largePoint);
  x = int(random(img.width));
  y = int(random(img.height));
  color pix = img.get(x, y);
  fill(pix, 128);
  ellipse(left + x, top + y, pointillize, pointillize);
  
  /* create a new OscMessage with an address pattern, in this case /test. */
 // OscMessage myOscMessage = new OscMessage("/test");
  OscMessage myOscMessage;
  myOscMessage = new OscMessage("/test");

  /* add a value (an integer) to the OscMessage */
  myOscMessage.add(x); 
  println( myOscMessage); 
  // println(myBroadcastLocation);
  /* send the OscMessage to a remote location specified in myNetAddress */
  oscP5.send(myOscMessage, myBroadcastLocation);
}
